@@ -10,7 +10,7 @@ API
 .. autofunction:: process_input
 
 """
-import logging
+
 import os
 import warnings
 from os.path import join
@@ -21,9 +21,10 @@ import yaml
 from schema import SchemaError
 from scm.plams import Molecule
 
-from qmflows.settings import Settings
+from qmflows import Settings
 from qmflows.type_hints import PathLike
 
+from .. import logger
 from ..common import DictConfig, UniqueSafeLoader, valence_electrons
 from .schemas import (schema_absorption_spectrum, schema_coop,
                       schema_cp2k_general_settings,
@@ -34,9 +35,6 @@ from .schemas import (schema_absorption_spectrum, schema_coop,
                       schema_single_points)
 from .templates import create_settings_from_template
 
-logger = logging.getLogger(__name__)
-
-
 schema_workflows = {
     'absorption_spectrum': schema_absorption_spectrum,
     'derivative_couplings': schema_derivative_couplings,
@@ -82,7 +80,7 @@ def process_input(input_file: PathLike, workflow_name: str) -> DictConfig:
 
     except SchemaError as e:
         msg = f"There was an error in the input yaml provided:\n{e}"
-        print(msg)
+        logger.warning(msg)
         raise
 
 
